summaryrefslogtreecommitdiff
path: root/lisp/org
diff options
context:
space:
mode:
Diffstat (limited to 'lisp/org')
-rw-r--r--lisp/org/ol-eww.el2
-rw-r--r--lisp/org/org-compat.el4
2 files changed, 3 insertions, 3 deletions
diff --git a/lisp/org/ol-eww.el b/lisp/org/ol-eww.el
index 0bd1b5b926c..d1bb5195107 100644
--- a/lisp/org/ol-eww.el
+++ b/lisp/org/ol-eww.el
@@ -48,7 +48,7 @@
(require 'cl-lib)
(require 'eww)
-;; For Emacs < 25.
+;; For Emacsen < 25.
(defvar eww-current-title)
(defvar eww-current-url)
diff --git a/lisp/org/org-compat.el b/lisp/org/org-compat.el
index bbad4ae635d..15f0daa91ae 100644
--- a/lisp/org/org-compat.el
+++ b/lisp/org/org-compat.el
@@ -1,4 +1,4 @@
;;; org-compat.el --- Compatibility Code for Older Emacs -*- lexical-binding: t; -*-
;; Copyright (C) 2004-2022 Free Software Foundation, Inc.
@@ -929,7 +929,7 @@ Pass COLUMN and FORCE to `move-to-column'."
"Define NAME as a new error signal.
MESSAGE is a string that will be output to the echo area if such
an error is signaled without being caught by a `condition-case'.
-Implements `define-error' for older versions of Emacs."
+Implements `define-error' for older emacsen."
(if (fboundp 'define-error) (define-error name message)
(put name 'error-conditions
(copy-sequence (cons name (get 'error 'error-conditions))))))
@@ -1,4 +1,4 @@
-;;; org-compat.el --- Compatibility Code for Older Emacs -*- lexical-binding: t; -*-
+;;; org-compat.el --- Compatibility Code for Older Emacsen -*- lexical-binding: t; -*-
;; Copyright (C) 2004-2022 Free Software Foundation, Inc.